@@ -68,6 +68,7 @@ class startControl(QThread):
         HAMLIB_PORT = "'9537'"
         self.gqrxIPv = "'127.0.0.1'"
         GQRX_PORT = "'9536'"
+        print (TCP_IP, HAMLIB_PORT, self.gqrxIPv, GQRX_PORT)
         sockGqrx = socket.create_connection((self.gqrxIPv, GQRX_PORT))
         sockHamlib = socket.create_connection((TCP_IP, HAMLIB_PORT))
             #sockHamlib = socket.socket(socket.AF_INET, socket.SOCK_STREAM) 
@@ -80,7 +81,7 @@ class startControl(QThread):
         #server_address2 = (self.gqrxIPv, GQRX_PORT)
         #sockGqrx.bind(server_address2)
         #sockGqrx.connect(server_address)
-        sockGqrx = socket.create_connection((self.gqrxIPv, GQRX_PORT))
+        #sockGqrx = socket.create_connection((self.gqrxIPv, GQRX_PORT))
         rig_freq = 0
         gqrx_freq = 0
         old_rig_freq = 0
@@ -93,6 +94,7 @@ class startControl(QThread):
         data = 0
                 
         gqrx_freq = self.getfreq(self.gqrxIPv, GQRX_PORT, 'gqrx', sockGqrx)
+        print (gqrx_freq)
         if gqrx_freq.find('\n') != -1:
             gqrx_freq = gqrx_freq[0:gqrx_freq.find('\n')]
         else:
